@@ -53,6 +53,7 @@ from .signer import sign_v4_s3
 @unique
 class _COMMAND(Enum):
     """Admin Command enumerations."""
+    ACCOUNT_INFO = "accountinfo"
     ADD_USER = "add-user"
     USER_INFO = "user-info"
     LIST_USERS = "list-users"
@@ -322,6 +323,15 @@ class MinioAdmin:
         )
         return response.data.decode()
 
+    def account_info(self, prefix_usage: bool = False) -> str:
+        """Get usage information for the authenticating account"""
+        response = self._url_open(
+            "GET",
+            _COMMAND.ACCOUNT_INFO,
+            query_params={"prefix-usage": "true"} if prefix_usage else None,
+        )
+        return response.data.decode()
+
     def user_add(self, access_key: str, secret_key: str) -> str:
         """Create user with access and secret keys"""
         body = json.dumps(
@@ -847,8 +857,21 @@ class MinioAdmin:
                 "POST",
                 command,
                 body=encrypt(body, self._provider.retrieve().secret_key),
+                preload_content=False,
             )
-            return response.data.decode()
+            if (
+                    command in [
+                        _COMMAND.IDP_BUILTIN_POLICY_ATTACH,
+                        _COMMAND.IDP_BUILTIN_POLICY_DETACH,
+                    ] and
+                    response.status in [201, 204]
+            ):
+                # Older MinIO servers do not return response.
+                response.close()
+                response.release_conn()
+                return ""
+            data = decrypt(response, self._provider.retrieve().secret_key)
+            return data.decode()
         raise ValueError("either user or group must be set")
 
     def attach_policy_ldap(
